@@ -44,33 +44,31 @@ while (!file.access(openbugs, mode = 0) == 0 || !file.access(openbugs, mode = 1)
 
 # 10.1 Simple logistic regression model . . . . . . . . . . . . . . . . .130
 
-bang1$denomb <- bang1$cons
-
-(mymodel1 <- runMLwiN(logit(use, denomb) ~ 1 + age, D = "Binomial", estoptions = list(EstM = 1), data = bang1))
+(mymodel1 <- runMLwiN(logit(use) ~ 1 + age, D = "Binomial", estoptions = list(EstM = 1), data = bang1))
 summary(mymodel1@chains[, "FP_age"])
 sixway(mymodel1@chains[, "FP_age", drop = FALSE], "beta_1")
 
 ## 15,000 iterations
-(mymodel2 <- runMLwiN(logit(use, denomb) ~ 1 + age, D = "Binomial", estoptions = list(EstM = 1, mcmcMeth = list(iterations = 15000)), 
+(mymodel2 <- runMLwiN(logit(use) ~ 1 + age, D = "Binomial", estoptions = list(EstM = 1, mcmcMeth = list(iterations = 15000)), 
   data = bang1))
 sixway(mymodel1@chains[, "FP_age", drop = FALSE], "beta_1")
 
 ## Change to 5000 iterations by default
-(mymodel3 <- runMLwiN(logit(use, denomb) ~ 1 + age + lc, D = "Binomial", estoptions = list(EstM = 1), data = bang1))
+(mymodel3 <- runMLwiN(logit(use) ~ 1 + age + lc, D = "Binomial", estoptions = list(EstM = 1), data = bang1))
 
 # 10.2 Random effects logistic regression model . . . . . . . . . . . . .136
 
-(mymodel4 <- runMLwiN(logit(use, denomb) ~ 1 + age + lc + (1 | district), D = "Binomial", estoptions = list(EstM = 1), 
+(mymodel4 <- runMLwiN(logit(use) ~ 1 + age + lc + (1 | district), D = "Binomial", estoptions = list(EstM = 1), 
   data = bang1))
 summary(mymodel4@chains[, "RP2_var_Intercept"])
 sixway(mymodel4@chains[, "RP2_var_Intercept", drop = FALSE], "sigma2u0")
 
 # 10.3 Random coefficients for area type . . . . . . . . . . . . . . . . 139
 
-(mymodel5 <- runMLwiN(logit(use, denomb) ~ 1 + age + lc + urban + (1 | district), D = "Binomial", estoptions = list(EstM = 1), 
+(mymodel5 <- runMLwiN(logit(use) ~ 1 + age + lc + urban + (1 | district), D = "Binomial", estoptions = list(EstM = 1), 
   data = bang1))
 
-(mymodel6 <- runMLwiN(logit(use, denomb) ~ 1 + age + lc + urban + (1 + urban | district), D = "Binomial", estoptions = list(EstM = 1), 
+(mymodel6 <- runMLwiN(logit(use) ~ 1 + age + lc + urban + (1 + urban | district), D = "Binomial", estoptions = list(EstM = 1), 
   data = bang1))
 
 # 10.4 Probit regression . . . . . . . . . . . . . . . . . . . . . . . . 141
@@ -78,11 +76,11 @@ sixway(mymodel4@chains[, "RP2_var_Intercept", drop = FALSE], "sigma2u0")
 # 10.5 Running a probit regression in MLwiN . . . . . . . . . . . . . . .142
 
 ## Gibbs
-(mymodel7 <- runMLwiN(probit(use, denomb) ~ 1 + age + lc + urban + (1 + urban | district), D = "Binomial", estoptions = list(EstM = 1, 
+(mymodel7 <- runMLwiN(probit(use) ~ 1 + age + lc + urban + (1 + urban | district), D = "Binomial", estoptions = list(EstM = 1, 
   mcmcMeth = list(fixM = 1, residM = 1)), data = bang1))
 
 ## Univariate MH by default
-(mymodel8 <- runMLwiN(probit(use, denomb) ~ 1 + age + lc + urban + (1 + urban | district), D = "Binomial", estoptions = list(EstM = 1), 
+(mymodel8 <- runMLwiN(probit(use) ~ 1 + age + lc + urban + (1 + urban | district), D = "Binomial", estoptions = list(EstM = 1), 
   data = bang1))
 
 cat("The mean parameter estimates\n")
@@ -105,14 +103,14 @@ print(sdtable)
 
 # 10.6 Comparison with WinBUGS . . . . . . . . . . . . . . . . . . . . . 144
 
-mymodel9 <- runMLwiN(logit(use, denomb) ~ 1 + age + (1 | district), D = "Binomial", estoptions = list(EstM = 1), BUGO = c(version = 4, 
+mymodel9 <- runMLwiN(logit(use) ~ 1 + age + (1 | district), D = "Binomial", estoptions = list(EstM = 1), BUGO = c(version = 4, 
   n.chains = 1, debug = FALSE, seed = 1, bugs = openbugs, OpenBugs = TRUE), data = bang1)
 
 summary(mymodel9)
 summary(mymodel9[, "beta[1]"])
 sixway(mymodel9[, "beta[1]", drop = FALSE])
 
-(mymodel10 <- runMLwiN(logit(use, denomb) ~ 1 + age + (1 | district), D = "Binomial", estoptions = list(EstM = 1), 
+(mymodel10 <- runMLwiN(logit(use) ~ 1 + age + (1 | district), D = "Binomial", estoptions = list(EstM = 1), 
   data = bang1))
 
 summary(mymodel10@chains[, "FP_Intercept"])
